@@ -4,7 +4,6 @@
 import os
 from operator import itemgetter
 
-import libimagequant as liq
 from openpyxl import Workbook
 from openpyxl.styles import Font, PatternFill
 from openpyxl.styles.colors import Color
@@ -39,17 +38,26 @@ def quantize(rgb=None, rgbmap=None):
     import numpy as np
     colorlist = list(rgbmap.keys())
     colors = len(colorlist)
-    X = np.array([[t[0] / 255.0, t[1] / 255.0, t[2] / 255.0] for t in colorlist])
+    X = np.array(colorlist)
     clusters = 65535
-    kmeans = KMeans(n_clusters=clusters, verbose=2, random_state=0, init='random').fit(X)
+    kmeans = KMeans(n_clusters=clusters, verbose=2,
+                    random_state=0, init='k-means++', algorithm='full', n_init=1).fit(X)
     result = kmeans.labels_
-    remapped = {colorlist[k]: colorlist[result[k]] for k in range(colors)}
+    centers = kmeans.cluster_centers_
+    clist = [[] for x in range(colors)]
+    for idx, r in enumerate(result):
+        clist[r].append(idx)
+    
+    remapped = {}
+    for idx, tup in enumerate(colorlist):
+        r, g, b = centers[idx]
+        remapped[tup] = (r, g, b)
 
     new_rgb = []
     for tup in rgb:
         new_rgb.append(remapped[tup])
 
-    return new_rgb, remapped, 65535
+    return new_rgb, remapped, clusters
 
 
 def get_image_color_dict(im, size_im):
